@@ -2,8 +2,7 @@
 /* vim: set ts=4 nowrap ai expandtab sw=4: */
 
 #include <glib.h>
-#include "rsvg.h"
-#include "rsvg-compat.h"
+#include "librsvg/rsvg.h"
 #include "test-utils.h"
 
 static void
@@ -29,7 +28,6 @@ main (int argc, char *argv[])
     GFile *base, *crash;
     int result;
 
-    RSVG_G_TYPE_INIT;
     g_test_init (&argc, &argv, NULL);
 
     if (argc < 2) {
